@@ -387,7 +387,14 @@ help_display (void)
 	GError *error;
 
 	error = NULL;
+#if GTK_CHECK_VERSION (3, 22, 0)
+	gtk_show_uri_on_window (NULL,
+                                "help:mate-user-guide/prefs-screensaver",
+                                GDK_CURRENT_TIME,
+                                &error);
+#else
 	gtk_show_uri (NULL, "help:mate-user-guide/prefs-screensaver", GDK_CURRENT_TIME, &error);
+#endif
 
 	if (error != NULL)
 	{
@@ -935,7 +942,7 @@ time_to_string_text (long time)
 	char *secs, *mins, *hours, *string;
 	int   sec, min, hour;
 
-	int n, inc_len, len_minutes;
+	int   inc_len, len_minutes;
 
 	sec = time % 60;
 	time = time - sec;
@@ -960,7 +967,7 @@ time_to_string_text (long time)
 
 	len_minutes = 0;
 
-	for (n = 2; n < 60; n++)
+	for (int n = 2; n < 60; n++)
 	{
 		if (n < 10)
 		{
@@ -1277,9 +1284,13 @@ constrain_list_size (GtkWidget      *widget,
 {
 	GtkRequisition req;
 	int            max_height;
+	int            sc_height;
 
 	/* constrain height to be the tree height up to a max */
-	max_height = (gdk_screen_get_height (gtk_widget_get_screen (widget))) / 4;
+	gdk_window_get_geometry (gdk_screen_get_root_window (gtk_widget_get_screen (widget)),
+				 NULL, NULL, NULL, &sc_height);
+
+	max_height = sc_height / 4;
 
 	gtk_widget_get_preferred_size (to_size, &req, NULL);
 	allocation->height = MIN (req.height, max_height);
